@@ -32,6 +32,7 @@ class NeedleEye(Benchmark):
 
     .. [1] Gavana, A. Global Optimization Benchmarks and AMPGO retrieved 2015
     """
+    change_dimensionality = True
 
     def __init__(self, dimensions=2):
         Benchmark.__init__(self, dimensions)
@@ -40,7 +41,6 @@ class NeedleEye(Benchmark):
 
         self.global_optimum = [[0.0 for _ in range(self.N)]]
         self.fglob = 1.0
-        self.change_dimensionality = True
 
     def fun(self, x, *args):
         self.nfev += 1
