@@ -102,6 +102,52 @@ class Bench(Benchmark):
     )
 
 
+class BatchedSolveBench(Benchmark):
+    params = [
+        [(100, 10, 10), (100, 20, 20), (100, 100)],
+        ["gen", "pos", "sym", "diagonal", "tridiagonal"],
+        ["scipy/detect", "scipy/assume", "numpy"]
+    ]
+    param_names = ["shape", "structure" ,"module"]
+
+    def setup(self, shape, structure, module):
+        a = random(shape)
+        # larger diagonal ensures non-singularity:
+        for i in range(shape[-1]):
+            a[..., i, i] = 10*(.1+a[..., i, i])
+
+        if structure == "pos":
+            self.a = a @ a.mT
+        elif structure == "sym":
+            self.a = a + a.mT
+        elif structure == "diagonal":
+            self.a = np.zeros_like(a)
+            for i in range(shape[-1]):
+                self.a[..., i, i] = a[..., i, i]
+        elif structure == "tridiagonal":
+            self.a = np.zeros_like(a)
+            for i in range(shape[-1]):
+                self.a[..., i, i] = a[..., i, i]
+            for i in range(shape[-1]-1):
+                self.a[..., i+1, i] = a[..., i+1, i]
+            for i in range(shape[-1]-1):
+                self.a[..., i, i+1] = a[..., i, i+1]
+        else:
+            self.a = a
+
+        self.b = random([a.shape[-1]])
+
+        self.kwd = {}
+        if module.split("/")[-1] == "assume":
+            self.kwd = {"assume_a": structure}
+
+    def time_solve(self, shape, structure, module):
+        if module == 'numpy':
+            nl.solve(self.a, self.b)
+        else:
+            sl.solve(self.a, self.b, check_finite=False, **self.kwd)
+
+
 class Norm(Benchmark):
     params = [
         [(20, 20), (100, 100), (1000, 1000), (20, 1000), (1000, 20)],
