@@ -1,13 +1,13 @@
 import itertools
+import warnings
 
 import numpy as np
 from numpy import (arange, array, dot, zeros, identity, conjugate, transpose,
                    float32)
-from numpy.random import random
 
 from numpy.testing import (assert_equal, assert_almost_equal, assert_,
                            assert_array_almost_equal, assert_allclose,
-                           assert_array_equal, suppress_warnings)
+                           assert_array_equal)
 import pytest
 from pytest import raises as assert_raises
 
@@ -19,12 +19,18 @@ from scipy.linalg import (solve, inv, det, lstsq, pinv, pinvh, norm,
 from scipy.linalg._testutils import assert_no_overwrite
 from scipy._lib._testutils import check_free_memory, IS_MUSL
 from scipy.linalg.blas import HAS_ILP64
+from scipy.conftest import skip_xp_invalid_arg
 
 REAL_DTYPES = (np.float32, np.float64, np.longdouble)
 COMPLEX_DTYPES = (np.complex64, np.complex128, np.clongdouble)
 DTYPES = REAL_DTYPES + COMPLEX_DTYPES
 
 
+parametrize_overwrite_arg = pytest.mark.parametrize(
+    "overwrite_kw", [{"overwrite_a": True}, {"overwrite_a": False}, {}]
+)
+
+
 def _eps_cast(dtyp):
     """Get the epsilon for dtype, possibly downcast to BLAS types."""
     dt = dtyp
@@ -534,10 +540,6 @@ class TestSolveHBanded:
 
 
 class TestSolve:
-    def setup_method(self):
-        np.random.seed(1234)
-
-    @pytest.mark.thread_unsafe
     def test_20Feb04_bug(self):
         a = [[1, 1], [1.0, 0]]  # ok
         x0 = solve(a, [1, 0j])
@@ -631,8 +633,9 @@ class TestSolve:
             assert_array_almost_equal(dot(a, x), b)
 
     def test_nils_20Feb04(self):
+        rng = np.random.default_rng(1234)
         n = 2
-        A = random([n, n])+random([n, n])*1j
+        A = rng.random([n, n])+rng.random([n, n])*1j
         X = zeros((n, n), 'D')
         Ainv = inv(A)
         R = identity(n)+identity(n)*0j
@@ -642,47 +645,50 @@ class TestSolve:
         assert_array_almost_equal(X, Ainv)
 
     def test_random(self):
-
+        rng = np.random.default_rng(1234)
         n = 20
-        a = random([n, n])
+        a = rng.random([n, n])
         for i in range(n):
             a[i, i] = 20*(.1+a[i, i])
         for i in range(4):
-            b = random([n, 3])
+            b = rng.random([n, 3])
             x = solve(a, b)
             assert_array_almost_equal(dot(a, x), b)
 
     def test_random_complex(self):
+        rng = np.random.default_rng(1234)
         n = 20
-        a = random([n, n]) + 1j * random([n, n])
+        a = rng.random([n, n]) + 1j * rng.random([n, n])
         for i in range(n):
             a[i, i] = 20*(.1+a[i, i])
         for i in range(2):
-            b = random([n, 3])
+            b = rng.random([n, 3])
             x = solve(a, b)
             assert_array_almost_equal(dot(a, x), b)
 
     def test_random_sym(self):
+        rng = np.random.default_rng(1234)
         n = 20
-        a = random([n, n])
+        a = rng.random([n, n])
         for i in range(n):
             a[i, i] = abs(20*(.1+a[i, i]))
             for j in range(i):
                 a[i, j] = a[j, i]
         for i in range(4):
-            b = random([n])
+            b = rng.random([n])
             x = solve(a, b, assume_a="pos")
             assert_array_almost_equal(dot(a, x), b)
 
     def test_random_sym_complex(self):
+        rng = np.random.default_rng(1234)
         n = 20
-        a = random([n, n])
-        a = a + 1j*random([n, n])
+        a = rng.random([n, n])
+        a = a + 1j*rng.random([n, n])
         for i in range(n):
             a[i, i] = abs(20*(.1+a[i, i]))
             for j in range(i):
                 a[i, j] = conjugate(a[j, i])
-        b = random([n])+2j*random([n])
+        b = rng.random([n])+2j*rng.random([n])
         for i in range(2):
             x = solve(a, b, assume_a="pos")
             assert_array_almost_equal(dot(a, x), b)
@@ -777,7 +783,6 @@ class TestSolve:
         b = np.arange(9)[:, None]
         assert_raises(LinAlgError, solve, a, b)
 
-    @pytest.mark.thread_unsafe
     @pytest.mark.parametrize('structure',
                              ('diagonal', 'tridiagonal', 'lower triangular',
                               'upper triangular', 'symmetric', 'hermitian',
@@ -788,11 +793,10 @@ class TestSolve:
         d = np.logspace(0, 50, n)
         A = np.diag(d)
         b = rng.random(size=n)
-        message = "Ill-conditioned matrix..."
+        message = "(Ill-conditioned matrix|An ill-conditioned matrix)"
         with pytest.warns(LinAlgWarning, match=message):
             solve(A, b, assume_a=structure)
 
-    @pytest.mark.thread_unsafe
     @pytest.mark.parametrize('structure',
                              ('diagonal', 'tridiagonal', 'lower triangular',
                               'upper triangular', 'symmetric', 'hermitian',
@@ -806,7 +810,8 @@ class TestSolve:
 
     def test_multiple_rhs(self):
         a = np.eye(2)
-        b = np.random.rand(2, 12)
+        rng = np.random.default_rng(1234)
+        b = rng.random((2, 12))
         x = solve(a, b)
         assert_array_almost_equal(x, b)
 
@@ -817,6 +822,7 @@ class TestSolve:
         x = solve(np.tril(A)/9, np.ones(3), transposed=False)
         assert_array_almost_equal(x, [9, -5.4, -1.2])
 
+    @pytest.mark.skip(reason="1. why? 2. deprecate the kwarg altogether?")
     def test_transposed_notimplemented(self):
         a = np.eye(3).astype(complex)
         with assert_raises(NotImplementedError):
@@ -832,56 +838,47 @@ class TestSolve:
     def test_assume_a_keyword(self):
         assert_raises(ValueError, solve, 1, 1, assume_a='zxcv')
 
-    @pytest.mark.skip(reason="Failure on OS X (gh-7500), "
-                             "crash on Windows (gh-8064)")
-    def test_all_type_size_routine_combinations(self):
-        sizes = [10, 100]
-        assume_as = ['gen', 'sym', 'pos', 'her']
-        dtypes = [np.float32, np.float64, np.complex64, np.complex128]
-        for size, assume_a, dtype in itertools.product(sizes, assume_as,
-                                                       dtypes):
-            is_complex = dtype in (np.complex64, np.complex128)
-            if assume_a == 'her' and not is_complex:
-                continue
+    @pytest.mark.parametrize("size", [10, 100])
+    @pytest.mark.parametrize("assume_a", ['gen', 'sym', 'pos', 'her', 'tridiagonal'])
+    @pytest.mark.parametrize(
+        "dtype", [np.float32, np.float64, np.complex64, np.complex128]
+    )
+    def test_all_type_size_routine_combinations(self, size, dtype, assume_a):
+        rng = np.random.default_rng(1234)
+        is_complex = dtype in (np.complex64, np.complex128)
 
-            err_msg = (f"Failed for size: {size}, assume_a: {assume_a},"
-                       f"dtype: {dtype}")
+        a = rng.standard_normal((size, size)).astype(dtype)
+        b = rng.standard_normal(size).astype(dtype)
+        if is_complex:
+            a += (1j*rng.standard_normal((size, size))).astype(dtype)
 
-            a = np.random.randn(size, size).astype(dtype)
-            b = np.random.randn(size).astype(dtype)
-            if is_complex:
-                a = a + (1j*np.random.randn(size, size)).astype(dtype)
+        if assume_a == 'sym':  # Can still be complex but only symmetric
+            a = a + a.T
+        elif assume_a == 'her':  # Handle hermitian matrices here instead
+            a = a + a.T.conj()
+        elif assume_a == 'pos':
+            a = a.T.conj() @ a + 0.1*np.eye(size)
+        elif assume_a == 'tridiagonal':
+            a = (np.diag(np.diag(a)) +
+                 np.diag(np.diag(a, 1), 1) +
+                 np.diag(np.diag(a, -1), -1)
+            )
 
-            if assume_a == 'sym':  # Can still be complex but only symmetric
-                a = a + a.T
-            elif assume_a == 'her':  # Handle hermitian matrices here instead
-                a = a + a.T.conj()
-            elif assume_a == 'pos':
-                a = a.conj().T.dot(a) + 0.1*np.eye(size)
+        tol = 1e-12 if dtype in (np.float64, np.complex128) else 1e-6
 
-            tol = 1e-12 if dtype in (np.float64, np.complex128) else 1e-6
+        if assume_a in ['gen', 'sym', 'her']:
+            # We revert the tolerance from before
+            #   4b4a6e7c34fa4060533db38f9a819b98fa81476c
+            if dtype in (np.float32, np.complex64):
+                tol *= 10
 
-            if assume_a in ['gen', 'sym', 'her']:
-                # We revert the tolerance from before
-                #   4b4a6e7c34fa4060533db38f9a819b98fa81476c
-                if dtype in (np.float32, np.complex64):
-                    tol *= 10
+        x = solve(a, b, assume_a=assume_a)
+        assert_allclose(a @ x, b, atol=tol * size, rtol=tol * size)
 
-            x = solve(a, b, assume_a=assume_a)
-            assert_allclose(a.dot(x), b,
-                            atol=tol * size,
-                            rtol=tol * size,
-                            err_msg=err_msg)
+        if assume_a == 'sym' and not is_complex:
+            x = solve(a, b, assume_a=assume_a, transposed=True)
+            assert_allclose(a @ x, b, atol=tol * size, rtol=tol * size)
 
-            if assume_a == 'sym' and dtype not in (np.complex64,
-                                                   np.complex128):
-                x = solve(a, b, assume_a=assume_a, transposed=True)
-                assert_allclose(a.dot(x), b,
-                                atol=tol * size,
-                                rtol=tol * size,
-                                err_msg=err_msg)
-
-    @pytest.mark.thread_unsafe
     @pytest.mark.parametrize('dt_a', [int, float, np.float32, complex, np.complex64])
     @pytest.mark.parametrize('dt_b', [int, float, np.float32, complex, np.complex64])
     def test_empty(self, dt_a, dt_b):
@@ -892,6 +889,13 @@ class TestSolve:
         assert x.size == 0
         dt_nonempty = solve(np.eye(2, dtype=dt_a), np.ones(2, dtype=dt_b)).dtype
         assert x.dtype == dt_nonempty
+        assert x.shape == np.linalg.solve(a, b).shape
+
+        a = np.ones((3, 0, 2, 2), dtype=dt_a)
+        b = np.ones((2, 4), dtype=dt_b)
+        x = solve(a, b)
+        assert x.shape == (3, 0, 2, 4)
+        assert x.dtype == dt_nonempty
 
     def test_empty_rhs(self):
         a = np.eye(2)
@@ -901,9 +905,9 @@ class TestSolve:
         assert_(x.shape == (2, 0), 'Returned empty array shape is wrong')
 
     @pytest.mark.parametrize('dtype', [np.float64, np.complex128])
-    # "pos" and "positive definite" need to be added
     @pytest.mark.parametrize('assume_a', ['diagonal', 'tridiagonal', 'banded',
                                           'lower triangular', 'upper triangular',
+                                          'pos', 'positive definite',
                                           'symmetric', 'hermitian', 'banded',
                                           'general', 'sym', 'her', 'gen'])
     @pytest.mark.parametrize('nrhs', [(), (5,)])
@@ -938,8 +942,7 @@ class TestSolve:
         elif assume_a in {'hermitian', 'her'}:
             A = A + A.conj().T
         elif assume_a in {'positive definite', 'pos'}:
-            A = A + A.T
-            A += np.diag(A.sum(axis=1))
+            A = A @ A.T.conj()
 
         if fortran:
             A = np.asfortranarray(A)
@@ -964,13 +967,186 @@ class TestSolve:
         # Check that `solve` correctly identifies the structure and returns
         # *exactly* the same solution whether `assume_a` is specified or not
         if assume_a != 'banded':  # structure detection removed for banded
-            assert_equal(solve(A_copy, b_copy, transposed=transposed), res)
+            assert_allclose(
+                solve(A_copy, b_copy, transposed=transposed), res, atol=1e-15
+            )
 
         # Check that overwrite was respected
         if not overwrite:
             assert_equal(A, A_copy)
             assert_equal(b, b_copy)
 
+    @pytest.mark.skipif(
+        np.__version__ < '2', reason="solve chokes on b.ndim == 1 in numpy < 2"
+    )
+    @pytest.mark.parametrize(
+        "assume_a",
+        [
+            None, "diagonal", "general", "upper triangular", "lower triangular", "pos",
+        ]
+    )
+    def test_vs_np_solve(self, assume_a):
+        e = np.eye(2)
+        a = np.arange(1, 4*3*2 + 1).reshape((4, 3, 2, 1, 1)) * e
+
+        b = np.ones(2)
+        assert_allclose(solve(a, b, assume_a=assume_a), np.linalg.solve(a, b))
+
+        b = np.ones((2, 1))
+        assert_allclose(solve(a, b, assume_a=assume_a), np.linalg.solve(a, b))
+
+        b = np.ones((2, 2)) * [1, 2]
+        assert_allclose(solve(a, b, assume_a=assume_a), np.linalg.solve(a, b))
+
+    def test_pos_lower(self):
+        # regression test for
+        # https://github.com/scipy/scipy/pull/23071#issuecomment-3085826112
+        rng = np.random.default_rng(0)
+        a = rng.normal(size=(4, 4))
+        a = np.tril(np.matmul(a, np.conj(a.T)))  # lower triangle of hermitian array
+        b = rng.normal(size=(4, 2))
+        out = solve(a, b, assume_a='pos', lower=True)
+
+        aa = a + a.T - np.diag(np.diag(a))   # the full hermitian array
+        result_np = np.linalg.solve(aa, b)
+        assert_allclose(out, result_np, atol=1e-15)
+
+        # repeat with uplo='U'
+        out = solve(a.T, b, assume_a='pos', lower=False)
+        assert_allclose(out, result_np, atol=1e-15)
+
+    def test_readonly(self):
+        a = np.eye(3)
+        a.flags.writeable = False
+        b = np.ones(3)
+        x = solve(a, b)
+        assert_allclose(x, b, atol=1e-14)
+
+    @parametrize_overwrite_arg
+    def test_batch_negative_stride(self, overwrite_kw):
+        a = np.arange(3*8).reshape(2, 3, 2, 2)
+        a = a[:, ::-1, :, :]
+        b = np.ones(2)
+        x = solve(a, b, **overwrite_kw)
+        assert x.shape == a.shape[:-1]
+        assert_allclose(a @ x[..., None] - b, 0, atol=1e-14)
+
+        # use b with a negative stride now
+        b = np.ones((2, 4))[:, ::-1]
+        x = solve(a, b, **overwrite_kw)
+        assert x.shape == a.shape[:-1] + (b.shape[-1],)
+        assert_allclose(a @ x - b, 0, atol=1e-14)
+
+    @parametrize_overwrite_arg
+    def test_core_negative_stride(self, overwrite_kw):
+        a = np.arange(3*8).reshape(2, 3, 2, 2)
+        a = a[:, :, ::-1, :]
+        b = np.ones(2)
+        x = solve(a, b, **overwrite_kw)
+
+        assert x.shape == a.shape[:-1]
+        assert_allclose(a @ x[..., None] - b, 0, atol=1e-14)
+
+        # use b with a negative stride now
+        b = np.ones((2, 4))[::-1, :]
+        x = solve(a, b, **overwrite_kw)
+        assert x.shape == a.shape[:-1] + (b.shape[-1],)
+        assert_allclose(a @ x - b, 0, atol=1e-14)
+
+    @parametrize_overwrite_arg
+    def test_core_non_contiguous(self, overwrite_kw):
+        a = np.arange(3*8*2).reshape(2, 3, 2, 4)
+        a = a[..., ::2]
+        b = np.ones(2)
+        x = solve(a, b, **overwrite_kw)
+        assert x.shape == a.shape[:-1]
+        assert_allclose(a @ x[..., None] - b, 0, atol=1e-14)
+
+        # use strided b now
+        b = np.ones(4)[::2]
+        x = solve(a, b, **overwrite_kw)
+        assert x.shape == a.shape[:-1]
+        assert_allclose(a @ x[..., None] - b, 0, atol=1e-14)
+
+    @parametrize_overwrite_arg
+    def test_batch_non_contiguous(self, overwrite_kw):
+        a = np.arange(3*8*2).reshape(2, 6, 2, 2)
+        a = a[:, ::2, ...]
+        b = np.ones(2)
+        x = solve(a, b, **overwrite_kw)
+        assert x.shape == a.shape[:-1]
+        assert_allclose(a @ x[..., None] - b, 0, atol=1e-14)
+
+        # use strided b now
+        b = np.ones((2, 6))[:, ::2]
+        x = solve(a, b, **overwrite_kw)
+        assert x.shape == a.shape[:-1] + (b.shape[-1],)
+        assert_allclose(a @ x - b, 0, atol=1e-14)
+
+    @parametrize_overwrite_arg
+    def test_batch_weird_strides(self, overwrite_kw):
+        a = np.arange(3*8*2).reshape(2, 3, 2, 2, 2)
+        a = a.transpose(1, 3, 4, 0, 2)
+
+        b = np.ones(2)
+        x = solve(a, b, **overwrite_kw)
+        assert x.shape == a.shape[:-1]
+        assert_allclose(a @ x[..., None] - b, 0, atol=1e-14)
+
+    def test_posdef_not_posdef(self):
+        # the `b` matrix is invertible but not positive definite
+        a = np.arange(9).reshape(3, 3)
+        A = a + a.T + np.eye(3)
+        b = np.ones(3)
+
+        # cholesky solver fails, and the routine falls back to the general inverse
+        x0 = solve(A, b)
+        assert_allclose(A @ x0, b, atol=1e-14)
+
+        # but it does not fall back if `assume_a` is given
+        with assert_raises(LinAlgError):
+            solve(A, b, assume_a='pos')
+
+    def test_diagonal(self):
+        a = np.stack([np.triu(np.ones((3, 3))), np.diag(np.arange(1, 4))])
+        b = np.ones(3)
+        x = solve(a, b)
+
+        # basic diagonal solve
+        assert_allclose(x[1, ...], 1 / np.arange(1, 4), atol=1e-14)
+
+        # ill-conditioned inputs warn
+        a = np.asarray([[1e30, 0], [0, 1]])
+        b = np.ones(2)
+        with pytest.warns(LinAlgWarning):
+            solve(a, b, assume_a="diagonal")
+
+        # singular input raises
+        a = np.asarray([[0, 0], [0, 1]])
+        b = np.ones(2)
+        with pytest.raises(LinAlgError):
+            solve(a, b, assume_a="diagonal")
+
+    def test_tridiagonal(self):
+        n = 4
+        a = -2*np.diag(np.ones(n)) + np.diag(np.ones(3), 1) + np.diag(np.ones(3), -1)
+        a = np.stack([np.triu(np.ones((n, n))), a])
+        b = np.ones(4)
+        x = solve(a, b)
+
+        # basic tridiag solve
+        assert_allclose(x[1, ...], np.asarray([-2., -3., -3., -2.]), atol=1e-15)
+
+        # ill-conditioned inputs warn
+        a[1, 0, 0] = 1e20
+        with pytest.warns(LinAlgWarning):
+            solve(a, b, assume_a="tridiagonal")
+
+        # singular inputss raise
+        a[1, 0, 0] = a[1, 0, 1] = 0
+        with pytest.raises(LinAlgError):
+            solve(a, b, assume_a="tridiagonal")
+
 
 class TestSolveTriangular:
 
@@ -1055,9 +1231,6 @@ class TestSolveTriangular:
 
 
 class TestInv:
-    def setup_method(self):
-        np.random.seed(1234)
-
     def test_simple(self):
         a = [[1, 2], [3, 4]]
         a_inv = inv(a)
@@ -1067,9 +1240,10 @@ class TestInv:
         assert_array_almost_equal(dot(a, a_inv), np.eye(3))
 
     def test_random(self):
+        rng = np.random.default_rng(1234)
         n = 20
         for i in range(4):
-            a = random([n, n])
+            a = rng.random([n, n])
             for i in range(n):
                 a[i, i] = 20*(.1+a[i, i])
             a_inv = inv(a)
@@ -1082,9 +1256,10 @@ class TestInv:
         assert_array_almost_equal(dot(a, a_inv), [[1, 0], [0, 1]])
 
     def test_random_complex(self):
+        rng = np.random.default_rng(1234)
         n = 20
         for i in range(4):
-            a = random([n, n])+2j*random([n, n])
+            a = rng.random([n, n])+2j*rng.random([n, n])
             for i in range(n):
                 a[i, i] = 20*(.1+a[i, i])
             a_inv = inv(a)
@@ -1103,11 +1278,250 @@ class TestInv:
         assert a_inv.size == 0
         assert a_inv.dtype == inv(np.eye(2, dtype=dt)).dtype
 
+        a = np.ones((3, 0, 2, 2), dtype=dt)
+        a_inv = inv(a)
+        assert a_inv.shape == (3, 0, 2, 2)
+
+        a = np.ones((3, 1, 0, 0), dtype=dt)
+        a_inv = inv(a)
+        assert a_inv.shape == (3, 1, 0, 0)
+
+    @pytest.mark.xfail(reason="TODO: re-enable overwrite_a")
+    def test_overwrite_a(self):
+        a = np.arange(1, 5).reshape(2, 2)
+        a_inv = inv(a, overwrite_a=True)
+        assert_allclose(a_inv @ a, np.eye(2), atol=1e-14)
+        assert not np.shares_memory(a, a_inv)    # int arrays are copied internally
+
+        # 2D F-ordered arrays of LAPACK-compatible dtypes: works inplace 
+        a = a.astype(float).copy(order='F')
+        a_inv = inv(a, overwrite_a=True)
+        assert np.shares_memory(a, a_inv)
+
+    def test_readonly(self):
+        a = np.eye(3)
+        a.flags.writeable = False
+
+        a_inv = inv(a)
+        assert_allclose(a_inv, a, atol=1e-14)
+
+    @pytest.mark.parametrize('dt', [int, float, np.float32, complex, np.complex64])
+    def test_batch_core_1x1(self, dt):
+        a = np.arange(3*2, dtype=dt).reshape(3, 2, 1, 1) + 1
+        a_inv = inv(a)
+        assert a_inv.shape == a.shape
+        assert_allclose(a @ a_inv, 1.)
+
+    @parametrize_overwrite_arg
+    def test_batch_zero_stride(self, overwrite_kw):
+        a = np.arange(3*2*2, dtype=float).reshape(3, 2, 2)
+        aa = a[None, ...]
+        a_inv = inv(aa, **overwrite_kw)
+        assert a_inv.shape == aa.shape
+        assert_allclose(aa @ a_inv, np.broadcast_to(np.eye(2), aa.shape), atol=2e-14)
+
+        aa = a[:, None, ...]
+        a_inv = inv(aa, **overwrite_kw)
+        assert a_inv.shape == aa.shape
+        assert_allclose(aa @ a_inv, np.broadcast_to(np.eye(2), aa.shape), atol=2e-14)
+
+    @parametrize_overwrite_arg
+    def test_batch_negative_stride(self, overwrite_kw):
+        a = np.arange(3*8).reshape(2, 3, 2, 2)
+        a = a[:, ::-1, :, :]
+        a_inv = inv(a, **overwrite_kw)
+        assert a_inv.shape == a.shape
+        assert_allclose(a @ a_inv, np.broadcast_to(np.eye(2), a.shape), atol=5e-14)
+
+    @parametrize_overwrite_arg
+    def test_core_negative_stride(self, overwrite_kw):
+        a = np.arange(3*8).reshape(2, 3, 2, 2)
+        a = a[:, :, ::-1, :]
+        a_inv = inv(a, **overwrite_kw)
+        assert a_inv.shape == a.shape
+        assert_allclose(a @ a_inv, np.broadcast_to(np.eye(2), a.shape), atol=5e-14)
+
+    @parametrize_overwrite_arg
+    def test_core_non_contiguous(self, overwrite_kw):
+        a = np.arange(3*8*2).reshape(2, 3, 2, 4)
+        a = a[..., ::2]
+        a_inv = inv(a, **overwrite_kw)
+        assert a_inv.shape == (2, 3, 2, 2)
+        assert_allclose(a @ a_inv, np.broadcast_to(np.eye(2), a.shape), atol=5e-14)
+
+    @parametrize_overwrite_arg
+    def test_batch_non_contiguous(self, overwrite_kw):
+        a = np.arange(3*8*2).reshape(2, 6, 2, 2)
+        a = a[:, ::2, ...]
+        a_inv = inv(a, **overwrite_kw)
+        assert a_inv.shape == (2, 3, 2, 2)
+        assert_allclose(a @ a_inv, np.broadcast_to(np.eye(2), a.shape), atol=2e-13)
+
+    @parametrize_overwrite_arg
+    def test_singular(self, overwrite_kw):
+        # 2D case: A singular matrix: raise
+
+        with assert_raises(LinAlgError):
+            inv(np.ones((2, 2)))
+
+        # batched case: If all slices are singlar, raise
+        with assert_raises(LinAlgError):
+            inv(np.ones((3, 2, 2)))
+
+        # XXX: shall we make this behavior configurable somehow?
+        # A "keep-going" option would be this:
+        # if some of the slices are singular and some are not,
+        # - singular slices are filled with nans
+        # - non-singular slices are inverted
+        # - there is no error
+        a = np.stack((np.ones((2, 2), dtype=complex), np.arange(4).reshape(2, 2)))
+        with assert_raises(LinAlgError):
+            inv(a)
+
+        # this would be true for a "keep-going" option
+        # assert np.isnan(a_inv[0, ...]).all()
+        # assert_allclose(a_inv[1, ...] @ a[1, ...],  np.eye(2), atol=1e-14)
+
+    def test_ill_cond(self):
+        a = np.diag([1., 1e-20])
+        with pytest.warns(LinAlgWarning):
+            inv(a)
+
+        a2 = np.stack([np.diag([1., 1e-20]), np.diag([1, 1]), np.diag([1, 1e-20])])
+        with pytest.warns(LinAlgWarning):
+            inv(a2)
+
+    def test_wrong_assume_a(self):
+        with assert_raises(KeyError):
+            inv(np.eye(2), assume_a="kaboom")
+
+    def test_posdef(self):
+        x = np.arange(25, dtype=float).reshape(5, 5)
+        y = x + x.T
+        y += 21*np.eye(5)
+
+        y_inv0 = inv(y)
+        y_inv1 = inv(y, assume_a="pos")
+
+        assert_allclose(y_inv1, y_inv0, atol=1e-15)
+
+        # check that the lower triangle is not referenced for `lower=False`
+        mask = np.where(1 - np.tri(*y.shape, -1) == 0, np.nan, 1)
+        y_inv2 = inv(y*mask, check_finite=False, assume_a="pos", lower=False)
+        assert_allclose(y_inv2, y_inv0, atol=1e-15)
+
+        # repeat with the upper triangle
+        y_inv3 = inv(y*mask.T, check_finite=False, assume_a="pos", lower=True)
+        assert_allclose(y_inv3, y_inv0, atol=1e-15)
+
+    @pytest.mark.parametrize('complex_', [False, True])
+    def test_posdef_not_posdef(self, complex_):
+        # the `b` matrix is invertible but not pos definite: test the "sym" fallback
+        a = np.arange(9).reshape(3, 3)
+        b = a + a.T + np.eye(3)
+        if complex_:
+            b = b + 1j*b
+
+        # cholesky solver fails, and the routine falls back to the symmetric inverse
+        b_inv0 = inv(b)
+        assert_allclose(b_inv0 @ b, np.eye(3), atol=3e-15)
+
+        # but it does not fall back if `assume_a` is given
+        with assert_raises(LinAlgError):
+            inv(b, assume_a='pos')
+
+        # test posdef fallback to the hermitian solver, too
+        if complex_:
+            a = np.arange(9).reshape(3, 3)
+            a = a + 1j*a
+            b = a + a.T.conj() + np.eye(3)
+            assert_allclose(inv(b) @ b, np.eye(3), atol=3e-15)
+
+    @pytest.mark.parametrize('complex_', [False, True])
+    @pytest.mark.parametrize('sym_herm', ['sym', 'her'])
+    def test_sym_her(self, complex_, sym_herm):
+        # test "sym" and "her" modes
+        a = np.arange(9).reshape(3, 3)
+        if complex_:
+            a = a + 1j*a
+
+        if sym_herm == "sym":
+            b = a + a.T
+        else:   # sym_herm == "herm":
+            b = a + a.T.conj()
+
+        b = b + np.eye(3)
+
+        b_inv0 = np.linalg.inv(b)
+        assert_allclose(b_inv0 @ b, np.eye(3), atol=1e-14)
+
+        b_inv1 = inv(b, assume_a=sym_herm)
+        assert_allclose(b_inv0, b_inv1, atol=1e-15)
+
+        # check that the "other" triangle is not referenced
+        mask = np.where(1 - np.tri(*a.shape, -1) == 0, np.nan, 1)
+        b_inv2 = inv(b*mask, check_finite=False, assume_a=sym_herm, lower=False)
+        assert_allclose(b_inv2, b_inv0, atol=1e-15)
+
+        # repeat with the upper triangle
+        b_inv3 = inv(b*mask.T, check_finite=False, assume_a=sym_herm, lower=True)
+        assert_allclose(b_inv3, b_inv0, atol=1e-15)
+
+    def test_triangular_1(self):
+        x = np.arange(25, dtype=float).reshape(5, 5)
+        y = x + x.T
+        y += 21*np.eye(5)
+        y_inv0 = inv(y, assume_a='upper triangular')
+
+        # check that upper triangular differs from posdef
+        y_inv_posdef = inv(y, assume_a='pos')
+        assert not np.allclose(y_inv0, y_inv_posdef)
+
+    def test_triangular_2(self):
+        y = np.ones(25, dtype=float).reshape(5, 5)
+
+        y_inv_0_u = inv(np.triu(y))
+        assert_allclose(y_inv_0_u @ np.triu(y), np.eye(5), atol=1e-15)
+
+        y_inv_1_u = inv(y, assume_a='upper triangular')
+        assert_allclose(y_inv_1_u @ np.triu(y), np.eye(5), atol=1e-15)
+
+        # check that the lower triangle is not referenced for "upper triangular"
+        mask = np.where(1 - np.tri(*y.shape, -1) == 0, np.nan, 1)
+        y_inv_2_u = inv(y*mask, check_finite=False, assume_a='upper triangular')
+        assert_allclose(y_inv_2_u @ np.triu(y), np.eye(5), atol=1e-15)
+
+        # repeat for the lower traingular matrix
+        y_inv_0_l = inv(np.tril(y))
+        assert_allclose(y_inv_0_l @ np.tril(y), np.eye(5), atol=1e-15)
+
+        y_inv_1_l = inv(y, assume_a='lower triangular')
+        assert_allclose(y_inv_1_l @ np.tril(y), np.eye(5), atol=1e-15)
+
+        # check that the lower triangle is not referenced for "lower triangular"
+        mask = np.where(1 - np.tri(*y.shape, -1) == 0, np.nan, 1)
+        y_inv_2_l = inv(y*mask.T, check_finite=False, assume_a='lower triangular')
+        assert_allclose(y_inv_2_l @ np.tril(y), np.eye(5), atol=1e-15)
+
+    def test_diagonal(self):
+        a = np.stack([np.triu(np.ones((3, 3))), np.diag(np.arange(1, 4))])
+        inv_a = inv(a)
+
+        # basic diagonal invert
+        assert_allclose(inv_a[1], np.diag(1 / np.arange(1, 4)), atol=1e-14)
+
+        # ill-conditioned inputs warn
+        a = np.asarray([[1e30, 0], [0, 1]])
+        with pytest.warns(LinAlgWarning):
+            inv(a, assume_a="diagonal")
+
+        # singular input raises
+        a = np.asarray([[0, 0], [0, 1]])
+        with pytest.raises(LinAlgError):
+            inv(a, assume_a="diagonal")
+
 
 class TestDet:
-    def setup_method(self):
-        self.rng = np.random.default_rng(1680305949878959)
-
     def test_1x1_all_singleton_dims(self):
         a = np.array([[1]])
         deta = det(a)
@@ -1126,13 +1540,14 @@ class TestDet:
         assert_equal(deta, [1.+3.j])
 
     def test_1by1_stacked_input_output(self):
-        a = self.rng.random([4, 5, 1, 1], dtype=np.float32)
+        rng = np.random.default_rng(1680305949878959)
+        a = rng.random([4, 5, 1, 1], dtype=np.float32)
         deta = det(a)
         assert deta.dtype.char == 'd'
         assert deta.shape == (4, 5)
         assert_allclose(deta, np.squeeze(a))
 
-        a = self.rng.random([4, 5, 1, 1], dtype=np.float32)*np.complex64(1.j)
+        a = rng.random([4, 5, 1, 1], dtype=np.float32)*np.complex64(1.j)
         deta = det(a)
         assert deta.dtype.char == 'D'
         assert deta.shape == (4, 5)
@@ -1140,12 +1555,13 @@ class TestDet:
 
     @pytest.mark.parametrize('shape', [[2, 2], [20, 20], [3, 2, 20, 20]])
     def test_simple_det_shapes_real_complex(self, shape):
-        a = self.rng.uniform(-1., 1., size=shape)
+        rng = np.random.default_rng(1680305949878959)
+        a = rng.uniform(-1., 1., size=shape)
         d1, d2 = det(a), np.linalg.det(a)
         assert_allclose(d1, d2)
 
-        b = self.rng.uniform(-1., 1., size=shape)*1j
-        b += self.rng.uniform(-0.5, 0.5, size=shape)
+        b = rng.uniform(-1., 1., size=shape)*1j
+        b += rng.uniform(-0.5, 0.5, size=shape)
         d3, d4 = det(b), np.linalg.det(b)
         assert_allclose(d3, d4)
 
@@ -1189,8 +1605,9 @@ class TestDet:
     @pytest.mark.parametrize('typ', [x for x in np.typecodes['All'][:20]
                                      if x not in 'gG'])
     def test_sample_compatible_dtype_input(self, typ):
+        rng = np.random.default_rng(1680305949878959)
         n = 4
-        a = self.rng.random([n, n]).astype(typ)  # value is not important
+        a = rng.random([n, n]).astype(typ)  # value is not important
         assert isinstance(det(a), (np.float64 | np.complex128))
 
     def test_incompatible_dtype_input(self):
@@ -1508,11 +1925,11 @@ class TestLstsq:
                                       err_msg=f"driver: {lapack_driver}")
 
     def test_check_finite(self):
-        with suppress_warnings() as sup:
+        with warnings.catch_warnings():
             # On (some) OSX this tests triggers a warning (gh-7538)
-            sup.filter(RuntimeWarning,
-                       "internal gelsd driver lwork query error,.*"
-                       "Falling back to 'gelss' driver.")
+            warnings.filterwarnings("ignore",
+                                    "internal gelsd driver lwork query error,.*"
+                                    "Falling back to 'gelss' driver.", RuntimeWarning)
 
         at = np.array(((1, 20), (-30, 4)))
         for dtype, bt, lapack_driver, overwrite, check_finite in \
@@ -1566,9 +1983,6 @@ class TestLstsq:
 
 
 class TestPinv:
-    def setup_method(self):
-        np.random.seed(1234)
-
     def test_simple_real(self):
         a = array([[1, 2, 3], [4, 5, 6], [7, 8, 10]], dtype=float)
         a_pinv = pinv(a)
@@ -1618,9 +2032,10 @@ class TestPinv:
         assert_array_almost_equal(a_pinv, expected)
 
     def test_atol_rtol(self):
+        rng = np.random.default_rng(1234)
         n = 12
         # get a random ortho matrix for shuffling
-        q, _ = qr(np.random.rand(n, n))
+        q, _ = qr(rng.random((n, n)))
         a_m = np.arange(35.0).reshape(7, 5)
         a = a_m.copy()
         a[0, 0] = 0.001
@@ -1653,10 +2068,6 @@ class TestPinv:
 
 
 class TestPinvSymmetric:
-
-    def setup_method(self):
-        np.random.seed(1234)
-
     def test_simple_real(self):
         a = array([[1, 2, 3], [4, 5, 6], [7, 8, 10]], dtype=float)
         a = np.dot(a, a.T)
@@ -1696,9 +2107,10 @@ class TestPinvSymmetric:
         assert_allclose(a @ p @ a, a, atol=1e-15)
 
     def test_atol_rtol(self):
+        rng = np.random.default_rng(1234)
         n = 12
         # get a random ortho matrix for shuffling
-        q, _ = qr(np.random.rand(n, n))
+        q, _ = qr(rng.random((n, n)))
         a = np.diag([4, 3, 2, 1, 0.99e-4, 0.99e-5] + [0.99e-6]*(n-6))
         a = q.T @ a @ q
         a_m = np.diag([4, 3, 2, 1, 0.99e-4, 0.] + [0.]*(n-6))
@@ -1803,12 +2215,12 @@ class TestMatrixNorms:
 
     def test_matrix_norms(self):
         # Not all of these are matrix norms in the most technical sense.
-        np.random.seed(1234)
+        rng = np.random.default_rng(1234)
         for n, m in (1, 1), (1, 3), (3, 1), (4, 4), (4, 5), (5, 4):
             for t in np.float32, np.float64, np.complex64, np.complex128, np.int64:
-                A = 10 * np.random.randn(n, m).astype(t)
+                A = 10 * rng.standard_normal((n, m)).astype(t)
                 if np.issubdtype(A.dtype, np.complexfloating):
-                    A = (A + 10j * np.random.randn(n, m)).astype(t)
+                    A += 10j * rng.standard_normal((n, m))
                     t_high = np.complex128
                 else:
                     t_high = np.float64
@@ -1923,8 +2335,8 @@ class TestSolveCirculant:
     def test_random_b_and_c(self):
         # Random b and c
         rng = np.random.RandomState(54321)
-        c = rng.randn(50)
-        b = rng.randn(50)
+        c = rng.standard_normal(50)
+        b = rng.standard_normal(50)
         x = solve_circulant(c, b)
         y = solve(circulant(c), b)
         assert_allclose(x, y)
@@ -1988,7 +2400,7 @@ class TestSolveCirculant:
 
 
 class TestMatrix_Balance:
-
+    @skip_xp_invalid_arg
     def test_string_arg(self):
         assert_raises(ValueError, matrix_balance, 'Some string for fail')
 
