@@ -1,9 +1,9 @@
 /*! \file
 Copyright (c) 2003, The Regents of the University of California, through
-Lawrence Berkeley National Laboratory (subject to receipt of any required
-approvals from U.S. Dept. of Energy)
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
 
-All rights reserved.
+All rights reserved. 
 
 The source code is distributed under BSD license, see the file License.txt
 at the top-level directory.
@@ -32,7 +32,7 @@ at the top-level directory.
  * a condition estimate are also provided. It performs the following steps:
  *
  *   1. If A is stored column-wise (A->Stype = SLU_NC):
- *
+ *  
  *      1.1. If options->Equil = YES, scaling factors are computed to
  *           equilibrate the system:
  *           options->Trans = NOTRANS:
@@ -58,7 +58,7 @@ at the top-level directory.
  *      1.4. Compute the reciprocal pivot growth factor.
  *
  *      1.5. If some U(i,i) = 0, so that U is exactly singular, then the
- *           routine returns with info = i. Otherwise, the factored form of
+ *           routine returns with info = i. Otherwise, the factored form of 
  *           A is used to estimate the condition number of the matrix A. If
  *           the reciprocal of the condition number is less than machine
  *           precision, info = A->ncol+1 is returned as a warning, but the
@@ -90,23 +90,23 @@ at the top-level directory.
  *               (diag(R)*A*diag(C))**H *inv(diag(R))*X = diag(C)*B
  *           Whether or not the system will be equilibrated depends on the
  *           scaling of the matrix A, but if equilibration is used, A' is
- *           overwritten by diag(R)*A'*diag(C) and B by diag(R)*B
+ *           overwritten by diag(R)*A'*diag(C) and B by diag(R)*B 
  *           (if trans='N') or diag(C)*B (if trans = 'T' or 'C').
  *
- *      2.2. Permute columns of transpose(A) (rows of A),
- *           forming transpose(A)*Pc, where Pc is a permutation matrix that
+ *      2.2. Permute columns of transpose(A) (rows of A), 
+ *           forming transpose(A)*Pc, where Pc is a permutation matrix that 
  *           usually preserves sparsity.
  *           For more details of this step, see sp_preorder.c.
  *
  *      2.3. If options->Fact != FACTORED, the LU decomposition is used to
- *           factor the transpose(A) (after equilibration if
+ *           factor the transpose(A) (after equilibration if 
  *           options->Fact = YES) as Pr*transpose(A)*Pc = L*U with the
  *           permutation Pr determined by partial pivoting.
  *
  *      2.4. Compute the reciprocal pivot growth factor.
  *
  *      2.5. If some U(i,i) = 0, so that U is exactly singular, then the
- *           routine returns with info = i. Otherwise, the factored form
+ *           routine returns with info = i. Otherwise, the factored form 
  *           of transpose(A) is used to estimate the condition number of the
  *           matrix A. If the reciprocal of the condition number
  *           is less than machine precision, info = A->nrow+1 is returned as
@@ -121,7 +121,7 @@ at the top-level directory.
  *           error bounds and backward error estimates for it.
  *
  *      2.8. If equilibration was used, the matrix X is premultiplied by
- *           diag(C) (if options->Trans = NOTRANS) or diag(R)
+ *           diag(C) (if options->Trans = NOTRANS) or diag(R) 
  *           (if options->Trans = TRANS or CONJ) so that it solves the
  *           original system before equilibration.
  *
@@ -141,10 +141,10 @@ at the top-level directory.
  *         Stype = SLU_NC or SLU_NR, Dtype = SLU_D, Mtype = SLU_GE.
  *         In the future, more general A may be handled.
  *
- *         On entry, If options->Fact = FACTORED and equed is not 'N',
+ *         On entry, If options->Fact = FACTORED and equed is not 'N', 
  *         then A must have been equilibrated by the scaling factors in
- *         R and/or C.
- *         On exit, A is not modified if options->Equil = NO, or if
+ *         R and/or C.  
+ *         On exit, A is not modified if options->Equil = NO, or if 
  *         options->Equil = YES but equed = 'N' on exit.
  *         Otherwise, if options->Equil = YES and equed is not 'N',
  *         A is scaled as follows:
@@ -167,13 +167,13 @@ at the top-level directory.
  *         is already in postorder.
  *
  *         If A->Stype = SLU_NR, column permutation vector of size A->nrow,
- *         which describes permutation of columns of transpose(A)
+ *         which describes permutation of columns of transpose(A) 
  *         (rows of A) as described above.
- *
+ * 
  * perm_r  (input/output) int*
- *         If A->Stype = SLU_NC, row permutation vector of size A->nrow,
+ *         If A->Stype = SLU_NC, row permutation vector of size A->nrow, 
  *         which defines the permutation matrix Pr, and is determined
- *         by partial pivoting.  perm_r[i] = j means row i of A is in
+ *         by partial pivoting.  perm_r[i] = j means row i of A is in 
  *         position j in Pr*A.
  *
  *         If A->Stype = SLU_NR, permutation vector of size A->ncol, which
@@ -186,7 +186,7 @@ at the top-level directory.
  *         new permutation determined by partial pivoting or diagonal
  *         threshold pivoting.
  *         Otherwise, perm_r is output argument.
- *
+ * 
  * etree   (input/output) int*,  dimension (A->ncol)
  *         Elimination tree of Pc'*A'*A*Pc.
  *         If options->Fact != FACTORED and options->Fact != DOFACT,
@@ -199,7 +199,7 @@ at the top-level directory.
  *         = 'N': No equilibration.
  *         = 'R': Row equilibration, i.e., A was premultiplied by diag(R).
  *         = 'C': Column equilibration, i.e., A was postmultiplied by diag(C).
- *         = 'B': Both row and column equilibration, i.e., A was replaced
+ *         = 'B': Both row and column equilibration, i.e., A was replaced 
  *                by diag(R)*A*diag(C).
  *         If options->Fact = FACTORED, equed is an input argument,
  *         otherwise it is an output argument.
@@ -213,7 +213,7 @@ at the top-level directory.
  *             otherwise, R is output.
  *         If options->zFact = FACTORED and equed = 'R' or 'B', each element
  *             of R must be positive.
- *
+ * 
  * C       (input/output) double*, dimension (A->ncol)
  *         The column scale factors for A or transpose(A).
  *         If equed = 'C' or 'B', A (if A->Stype = SLU_NC) or transpose(A)
@@ -223,7 +223,7 @@ at the top-level directory.
  *             otherwise, C is output.
  *         If options->Fact = FACTORED and equed = 'C' or 'B', each element
  *             of C must be positive.
- *
+ *         
  * L       (output) SuperMatrix*
  *	   The factor L from the factorization
  *             Pr*A*Pc=L*U              (if A->Stype SLU_= NC) or
@@ -243,7 +243,7 @@ at the top-level directory.
  *         to hold data structures for factors L and U.
  *         On exit, if fact is not 'F', L and U point to this array.
  *
- * lwork   (input) int
+ * lwork   (input) int_t
  *         Specifies the size of work array in bytes.
  *         = 0:  allocate space internally by system malloc;
  *         > 0:  use user-supplied work array of length lwork in bytes,
@@ -273,7 +273,7 @@ at the top-level directory.
  *                  B is overwritten by diag(R)*B.
  *
  * X       (output) SuperMatrix*
- *         X has types: Stype = SLU_DN, Dtype = SLU_Z, Mtype = SLU_GE.
+ *         X has types: Stype = SLU_DN, Dtype = SLU_Z, Mtype = SLU_GE. 
  *         If info = 0 or info = A->ncol+1, X contains the solution matrix
  *         to the original system of equations. Note that A and B are modified
  *         on exit if equed is not 'N', and the solution to the equilibrated
@@ -293,26 +293,26 @@ at the top-level directory.
  *         to working precision. This condition is indicated by a return
  *         code of info > 0.
  *
- * FERR    (output) double*, dimension (B->ncol)
- *         The estimated forward error bound for each solution vector
- *         X(j) (the j-th column of the solution matrix X).
- *         If XTRUE is the true solution corresponding to X(j), FERR(j)
- *         is an estimated upper bound for the magnitude of the largest
- *         element in (X(j) - XTRUE) divided by the magnitude of the
- *         largest element in X(j).  The estimate is as reliable as
- *         the estimate for RCOND, and is almost always a slight
+ * FERR    (output) double*, dimension (B->ncol)   
+ *         The estimated forward error bound for each solution vector   
+ *         X(j) (the j-th column of the solution matrix X).   
+ *         If XTRUE is the true solution corresponding to X(j), FERR(j) 
+ *         is an estimated upper bound for the magnitude of the largest 
+ *         element in (X(j) - XTRUE) divided by the magnitude of the   
+ *         largest element in X(j).  The estimate is as reliable as   
+ *         the estimate for RCOND, and is almost always a slight   
  *         overestimate of the true error.
  *         If options->IterRefine = NOREFINE, ferr = 1.0.
  *
  * BERR    (output) double*, dimension (B->ncol)
- *         The componentwise relative backward error of each solution
- *         vector X(j) (i.e., the smallest relative change in
+ *         The componentwise relative backward error of each solution   
+ *         vector X(j) (i.e., the smallest relative change in   
  *         any element of A or B that makes X(j) an exact solution).
  *         If options->IterRefine = NOREFINE, berr = 1.0.
  *
  * Glu      (input/output) GlobalLU_t *
  *          If options->Fact == SamePattern_SameRowPerm, it is an input;
- *              The matrix A will be factorized assuming that a
+ *              The matrix A will be factorized assuming that a 
  *              factorization of a matrix with the same sparsity pattern
  *              and similar numerical values was performed prior to this one.
  *              Therefore, this factorization will reuse both row and column
@@ -335,19 +335,19 @@ at the top-level directory.
  *        See slu_util.h for the definition of 'SuperLUStat_t'.
  *
  * info    (output) int*
- *         = 0: successful exit
- *         < 0: if info = -i, the i-th argument had an illegal value
- *         > 0: if info = i, and i is
- *              <= A->ncol: U(i,i) is exactly zero. The factorization has
- *                    been completed, but the factor U is exactly
- *                    singular, so the solution and error bounds
- *                    could not be computed.
+ *         = 0: successful exit   
+ *         < 0: if info = -i, the i-th argument had an illegal value   
+ *         > 0: if info = i, and i is   
+ *              <= A->ncol: U(i,i) is exactly zero. The factorization has   
+ *                    been completed, but the factor U is exactly   
+ *                    singular, so the solution and error bounds   
+ *                    could not be computed.   
  *              = A->ncol+1: U is nonsingular, but RCOND is less than machine
  *                    precision, meaning that the matrix is singular to
  *                    working precision. Nevertheless, the solution and
  *                    error bounds are computed because there are a number
  *                    of situations where the computed solution can be more
- *                    accurate than the value of RCOND would suggest.
+ *                    accurate than the value of RCOND would suggest.   
  *              > A->ncol+1: number of bytes allocated when memory allocation
  *                    failure occurred, plus A->ncol.
  * </pre>
@@ -356,13 +356,12 @@ at the top-level directory.
 void
 zgssvx(superlu_options_t *options, SuperMatrix *A, int *perm_c, int *perm_r,
        int *etree, char *equed, double *R, double *C,
-       SuperMatrix *L, SuperMatrix *U, void *work, int lwork,
-       SuperMatrix *B, SuperMatrix *X, double *recip_pivot_growth,
-       double *rcond, double *ferr, double *berr,
-       GlobalLU_t *Glu, mem_usage_t *mem_usage, SuperLUStat_t *stat, int *info )
+       SuperMatrix *L, SuperMatrix *U, void *work, int_t lwork,
+       SuperMatrix *B, SuperMatrix *X, double *recip_pivot_growth, 
+       double *rcond, double *ferr, double *berr, 
+       GlobalLU_t *Glu, mem_usage_t *mem_usage, SuperLUStat_t *stat, int_t *info )
 {
 
-
     DNformat  *Bstore, *Xstore;
     doublecomplex    *Bmat, *Xmat;
     int       ldb, ldx, nrhs;
@@ -372,9 +371,8 @@ zgssvx(superlu_options_t *options, SuperMatrix *A, int *perm_c, int *perm_r,
     trans_t   trant;
     char      norm[1];
     int       i, j, info1;
-    double    amax, anorm, colcnd, rowcnd, rcmax, rcmin;
+    double    amax, anorm, bignum, smlnum, colcnd, rowcnd, rcmax, rcmin;
     int       relax, panel_size;
-    double    diag_pivot_thresh;
     double    t0;      /* temporary time */
     double    *utime;
 
@@ -400,6 +398,8 @@ zgssvx(superlu_options_t *options, SuperMatrix *A, int *perm_c, int *perm_r,
     } else {
 	rowequ = strncmp(equed, "R", 1)==0 || strncmp(equed, "B", 1)==0;
 	colequ = strncmp(equed, "C", 1)==0 || strncmp(equed, "B", 1)==0;
+	smlnum = dmach("Safe minimum");   /* lamch_("Safe minimum"); */
+	bignum = 1. / smlnum;
     }
 
 #if 0
@@ -408,13 +408,13 @@ printf("dgssvx: Fact=%4d, Trans=%4d, equed=%c\n",
 #endif
 
     /* Test the input parameters */
-    if (options->Fact != DOFACT && options->Fact != SamePattern &&
-	options->Fact != SamePattern_SameRowPerm &&
-	options->Fact != FACTORED &&
-	options->Trans != NOTRANS && options->Trans != TRANS &&
-	options->Trans != CONJ &&
-	options->Equil != NO && options->Equil != YES)
-	*info = -1;
+    if ( (options->Fact != DOFACT && options->Fact != SamePattern &&
+	  options->Fact != SamePattern_SameRowPerm &&
+	  options->Fact != FACTORED) || 
+	 (options->Trans != NOTRANS && options->Trans != TRANS && 
+	  options->Trans != CONJ) ||
+	 (options->Equil != NO && options->Equil != YES) )
+	 *info = -1;
     else if ( A->nrow != A->ncol || A->nrow < 0 ||
 	      (A->Stype != SLU_NC && A->Stype != SLU_NR) ||
 	      A->Dtype != SLU_Z || A->Mtype != SLU_GE )
@@ -424,9 +424,6 @@ printf("dgssvx: Fact=%4d, Trans=%4d, equed=%c\n",
 	*info = -6;
     else {
 	if (rowequ) {
-      float smlnum, bignum;
-      smlnum = dmach("Safe minimum");  /* lamch_("Safe minimum"); */
-      bignum = 1. / smlnum;
 	    rcmin = bignum;
 	    rcmax = 0.;
 	    for (j = 0; j < A->nrow; ++j) {
@@ -439,9 +436,6 @@ printf("dgssvx: Fact=%4d, Trans=%4d, equed=%c\n",
 	    else rowcnd = 1.;
 	}
 	if (colequ && *info == 0) {
-      float smlnum, bignum;
-      smlnum = dmach("Safe minimum");  /* lamch_("Safe minimum"); */
-      bignum = 1. / smlnum;
 	    rcmin = bignum;
 	    rcmax = 0.;
 	    for (j = 0; j < A->nrow; ++j) {
@@ -458,7 +452,7 @@ printf("dgssvx: Fact=%4d, Trans=%4d, equed=%c\n",
 	    else if ( B->ncol < 0 ) *info = -13;
 	    else if ( B->ncol > 0 ) { /* no checking if B->ncol=0 */
 	         if ( Bstore->lda < SUPERLU_MAX(0, A->nrow) ||
-		      B->Stype != SLU_DN || B->Dtype != SLU_Z ||
+		      B->Stype != SLU_DN || B->Dtype != SLU_Z || 
 		      B->Mtype != SLU_GE )
 		*info = -13;
             }
@@ -477,19 +471,18 @@ printf("dgssvx: Fact=%4d, Trans=%4d, equed=%c\n",
 	input_error("zgssvx", &i);
 	return;
     }
-
+    
     /* Initialization for factor parameters */
     panel_size = sp_ienv(1);
     relax      = sp_ienv(2);
-    diag_pivot_thresh = options->DiagPivotThresh;
 
     utime = stat->utime;
-
+    
     /* Convert A to SLU_NC format when necessary. */
     if ( A->Stype == SLU_NR ) {
 	NRformat *Astore = A->Store;
 	AA = (SuperMatrix *) SUPERLU_MALLOC( sizeof(SuperMatrix) );
-	zCreate_CompCol_Matrix(AA, A->ncol, A->nrow, Astore->nnz,
+	zCreate_CompCol_Matrix(AA, A->ncol, A->nrow, Astore->nnz, 
 			       Astore->nzval, Astore->colind, Astore->rowptr,
 			       SLU_NC, A->Dtype, A->Mtype);
 	if ( notran ) { /* Reverse the transpose argument. */
@@ -508,7 +501,7 @@ printf("dgssvx: Fact=%4d, Trans=%4d, equed=%c\n",
 	t0 = SuperLU_timer_();
 	/* Compute row and column scalings to equilibrate the matrix A. */
 	zgsequ(AA, R, C, &rowcnd, &colcnd, &amax, &info1);
-
+	
 	if ( info1 == 0 ) {
 	    /* Equilibrate matrix A. */
 	    zlaqgs(AA, R, C, rowcnd, colcnd, amax, equed);
@@ -520,11 +513,11 @@ printf("dgssvx: Fact=%4d, Trans=%4d, equed=%c\n",
 
 
     if ( nofact ) {
-
+	
         t0 = SuperLU_timer_();
 	/*
 	 * Gnet column permutation vector perm_c[], according to permc_spec:
-	 *   permc_spec = NATURAL:  natural ordering
+	 *   permc_spec = NATURAL:  natural ordering 
 	 *   permc_spec = MMD_AT_PLUS_A: minimum degree on structure of A'+A
 	 *   permc_spec = MMD_ATA:  minimum degree on structure of A'*A
 	 *   permc_spec = COLAMD:   approximate minimum degree column ordering
@@ -538,17 +531,17 @@ printf("dgssvx: Fact=%4d, Trans=%4d, equed=%c\n",
 	t0 = SuperLU_timer_();
 	sp_preorder(options, AA, perm_c, etree, &AC);
 	utime[ETREE] = SuperLU_timer_() - t0;
-
-/*	printf("Factor PA = LU ... relax %d\tw %d\tmaxsuper %d\trowblk %d\n",
+    
+/*	printf("Factor PA = LU ... relax %d\tw %d\tmaxsuper %d\trowblk %d\n", 
 	       relax, panel_size, sp_ienv(3), sp_ienv(4));
 	fflush(stdout); */
-
+	
 	/* Compute the LU factorization of A*Pc. */
 	t0 = SuperLU_timer_();
 	zgstrf(options, &AC, relax, panel_size, etree,
                 work, lwork, perm_c, perm_r, L, U, Glu, stat, info);
 	utime[FACT] = SuperLU_timer_() - t0;
-
+	
 	if ( lwork == -1 ) {
 	    mem_usage->total_needed = *info - A->ncol;
 	    return;
@@ -583,7 +576,7 @@ printf("dgssvx: Fact=%4d, Trans=%4d, equed=%c\n",
         zgscon(norm, L, U, anorm, rcond, stat, &info1);
         utime[RCOND] = SuperLU_timer_() - t0;
     }
-
+    
     if ( nrhs > 0 ) {
         /* Scale the right hand side if equilibration was performed. */
         if ( notran ) {
@@ -602,11 +595,11 @@ printf("dgssvx: Fact=%4d, Trans=%4d, equed=%c\n",
         for (j = 0; j < nrhs; j++)  /* Save a copy of the right hand sides */
             for (i = 0; i < B->nrow; i++)
 	        Xmat[i + j*ldx] = Bmat[i + j*ldb];
-
+    
         t0 = SuperLU_timer_();
         zgstrs (trant, L, U, perm_c, perm_r, X, stat, &info1);
         utime[SOLVE] = SuperLU_timer_() - t0;
-
+    
         /* Use iterative refinement to improve the computed solution and compute
            error bounds and backward error estimates for it. */
         t0 = SuperLU_timer_();
