@@ -1,11 +1,10 @@
 #include <xsf/numpy.h>
+#include <xsf/bessel.h>
+#include <xsf/sph_harm.h>
 
 #include "sf_error.h"
-#include "xsf_special.h"
 
 extern const char *lpn_all_doc;
-extern const char *lpmn_doc;
-extern const char *clpmn_doc;
 extern const char *lqn_doc;
 extern const char *lqmn_doc;
 extern const char *rctj_doc;
