@@ -35,7 +35,7 @@
 #include <xsf/trig.h>
 #include <xsf/wright_bessel.h>
 #include <xsf/zeta.h>
-#include "xsf_special.h"
+#include "gen_harmonic.h"
 
 // This is the extension module for the NumPy ufuncs in SciPy's special module. To create such a ufunc, call
 // "xsf::numpy::ufunc" with a braced list of kernel functions that will become the ufunc overloads. There are
@@ -47,8 +47,10 @@
 
 extern const char *_cospi_doc;
 extern const char *_sinpi_doc;
+extern const char *_gen_harmonic_doc;
 extern const char *_log1mexp_doc;
 extern const char *_log1pmx_doc;
+extern const char *_normalized_gen_harmonic_doc;
 extern const char *airy_doc;
 extern const char *airye_doc;
 extern const char *bei_doc;
@@ -175,7 +177,6 @@ extern const char *spherical_in_doc;
 extern const char *spherical_in_d_doc;
 extern const char *spherical_kn_doc;
 extern const char *spherical_kn_d_doc;
-extern const char *sph_harm_doc;
 extern const char *struve_h_doc;
 extern const char *struve_l_doc;
 extern const char *tandg_doc;
@@ -235,6 +236,24 @@ PyMODINIT_FUNC PyInit__special_ufuncs() {
                           "_cospi", _cospi_doc);
     PyModule_AddObjectRef(_special_ufuncs, "_cospi", _cospi);
 
+    PyObject *_gen_harmonic =
+        xsf::numpy::ufunc({static_cast<xsf::numpy::ld_d>(gen_harmonic),
+                           static_cast<xsf::numpy::qd_d>(gen_harmonic),
+                           static_cast<xsf::numpy::dd_d>(gen_harmonic)},
+                           "_gen_harmonic", _gen_harmonic_doc);
+    PyModule_AddObjectRef(_special_ufuncs, "_gen_harmonic", _gen_harmonic);
+
+    // Define llld_d and qqqd_d here until they are added to xsf::numpy.
+    using llld_d = double (*)(long int, long int, long int, double);
+    using qqqd_d = double (*)(long long int, long long int, long long int, double);
+
+    PyObject *_normalized_gen_harmonic =
+        xsf::numpy::ufunc({static_cast<llld_d>(normalized_gen_harmonic),
+                           static_cast<qqqd_d>(normalized_gen_harmonic),
+                           static_cast<xsf::numpy::dddd_d>(normalized_gen_harmonic)},
+                          "_normalized_gen_harmonic", _normalized_gen_harmonic_doc);
+    PyModule_AddObjectRef(_special_ufuncs, "_normalized_gen_harmonic", _normalized_gen_harmonic);
+
     PyObject *_lambertw = xsf::numpy::ufunc(
         {static_cast<xsf::numpy::Dld_D>(xsf::lambertw), static_cast<xsf::numpy::Flf_F>(xsf::lambertw)}, "_lambertw",
         lambertw_doc);
@@ -1052,12 +1071,6 @@ PyMODINIT_FUNC PyInit__special_ufuncs() {
                            [](const npy_intp *dims, npy_intp *new_dims) {}));
     PyModule_AddObjectRef(_special_ufuncs, "sph_legendre_p", sph_legendre_p);
 
-    PyObject *sph_harm =
-        xsf::numpy::ufunc({static_cast<xsf::numpy::qqdd_D>(::sph_harm), static_cast<xsf::numpy::dddd_D>(::sph_harm),
-                           static_cast<xsf::numpy::qqff_F>(::sph_harm), static_cast<xsf::numpy::ffff_F>(::sph_harm)},
-                          "sph_harm", sph_harm_doc);
-    PyModule_AddObjectRef(_special_ufuncs, "sph_harm", sph_harm);
-
     PyObject *sph_harm_y =
         Py_BuildValue("(N, N, N)",
                       xsf::numpy::gufunc({xsf::numpy::compose{xsf::numpy::autodiff(), xsf::numpy::use_long_long_int()},
