@@ -30,7 +30,6 @@
 #include <xsf/trig.h>
 #include <xsf/wright_bessel.h>
 #include <xsf/zeta.h>
-#include "xsf_special.h"
 
 #include <xsf/cephes/cbrt.h>
 #include <xsf/cephes/erfinv.h>
@@ -289,14 +288,6 @@ npy_cdouble special_lambertw(npy_cdouble z, long k, double tol) {
     return to_ccomplex(xsf::lambertw(to_complex(z), k, tol));
 }
 
-npy_cdouble special_sph_harm(long m, long n, double theta, double phi) {
-    return to_ccomplex(::sph_harm(m, n, theta, phi));
-}
-
-npy_cdouble special_sph_harm_unsafe(double m, double n, double theta, double phi) {
-    return to_ccomplex(::sph_harm(static_cast<long>(m), static_cast<long>(n), theta, phi));
-}
-
 double cephes_expm1_wrap(double x) { return xsf::cephes::expm1(x); }
 
 double cephes_expn_wrap(Py_ssize_t n, double x) { return xsf::cephes::expn(static_cast<int>(n), x); }
@@ -595,16 +586,34 @@ double xsf_chdtrc(double df, double x) { return xsf::chdtrc(df, x); }
 
 double xsf_chdtri(double df, double y) { return xsf::chdtri(df, y); }
 
-double xsf_fdtr(double a, double b, double x) { return xsf::fdtr(a, b, x); }
-
-double xsf_fdtrc(double a, double b, double x) { return xsf::fdtrc(a, b, x); }
-
-double xsf_fdtri(double a, double b, double y) { return xsf::fdtri(a, b, y); }
-
 double xsf_gdtr(double a, double b, double x) { return xsf::gdtr(a, b, x); }
 
 double xsf_gdtrc(double a, double b, double x) { return xsf::gdtrc(a, b, x); }
 
+double special_gdtria(double p, double b, double x) { 
+    if (x == 0) {
+        return std::numeric_limits<double>::quiet_NaN();
+    }
+    if ((b == 0) & (p == 0)) {
+        if (std::isinf(x) && (x > 0)) {
+            return std::numeric_limits<double>::quiet_NaN();
+        }
+        return 0.0;
+    }
+    return xsf::gammaincinv(b, p) / x;
+}
+
+double special_gdtrix(double a, double b, double p) { 
+    if ((a == 0) && (b == 0)) {
+        return std::numeric_limits<double>::quiet_NaN();
+    }
+    // if a or b is positive infinite, return NaN
+    if ((std::isinf(a) || std::isinf(b)) && (a >= 0 && b >= 0)) {
+        return std::numeric_limits<double>::quiet_NaN();
+    }
+    return xsf::gammaincinv(b, p) / a;
+}
+
 double xsf_gdtrib(double a, double p, double x) { return xsf::gdtrib(a, p, x); }
 
 double xsf_kolmogorov(double x) { return xsf::kolmogorov(x); }
