@@ -1,6 +1,7 @@
 import warnings
 import numpy as np
 
+from scipy._lib._array_api import xp_capabilities
 from scipy._lib._util import check_random_state, MapWrapper, rng_integers, _contains_nan
 from scipy._lib._bunch import _make_tuple_bunch
 from scipy.spatial.distance import cdist
@@ -38,7 +39,7 @@ def _perm_test(x, y, stat, reps=1000, workers=-1, random_state=None):
     Parameters
     ----------
     x, y : ndarray
-        `x` and `y` have shapes `(n, p)` and `(n, q)`.
+        `x` and `y` have shapes ``(n, p)`` and ``(n, q)``.
     stat : float
         The sample test statistic.
     reps : int, optional
@@ -95,6 +96,7 @@ MGCResult = _make_tuple_bunch('MGCResult',
                               ['statistic', 'pvalue', 'mgc_dict'], [])
 
 
+@xp_capabilities(np_only=True)
 def multiscale_graphcorr(x, y, compute_distance=_euclidean_dist, reps=1000,
                          workers=1, is_twosamp=False, random_state=None):
     r"""Computes the Multiscale Graph Correlation (MGC) test statistic.
@@ -167,7 +169,7 @@ def multiscale_graphcorr(x, y, compute_distance=_euclidean_dist, reps=1000,
         An object containing attributes:
 
         statistic : float
-            The sample MGC test statistic within `[-1, 1]`.
+            The sample MGC test statistic within ``[-1, 1]``.
         pvalue : float
             The p-value obtained via permutation.
         mgc_dict : dict
@@ -177,7 +179,7 @@ def multiscale_graphcorr(x, y, compute_distance=_euclidean_dist, reps=1000,
                     A 2D representation of the latent geometry of the
                     relationship.
                 - opt_scale : (int, int)
-                    The estimated optimal scale as a `(x, y)` pair.
+                    The estimated optimal scale as a ``(x, y)`` pair.
                 - null_dist : list
                     The null distribution derived from the permuted matrices.
 
@@ -384,14 +386,14 @@ def _mgc_stat(distx, disty):
     Parameters
     ----------
     distx, disty : ndarray
-        `distx` and `disty` have shapes `(n, p)` and `(n, q)` or
-        `(n, n)` and `(n, n)`
+        `distx` and `disty` have shapes ``(n, p)`` and ``(n, q)`` or
+        ``(n, n)`` and ``(n, n)``
         if distance matrices.
 
     Returns
     -------
     stat : float
-        The sample MGC test statistic within `[-1, 1]`.
+        The sample MGC test statistic within ``[-1, 1]``.
     stat_dict : dict
         Contains additional useful additional returns containing the following
         keys:
@@ -399,7 +401,7 @@ def _mgc_stat(distx, disty):
             - stat_mgc_map : ndarray
                 MGC-map of the statistics.
             - opt_scale : (float, float)
-                The estimated optimal scale as a `(x, y)` pair.
+                The estimated optimal scale as a ``(x, y)`` pair.
 
     """
     # calculate MGC map and optimal scale
@@ -407,7 +409,7 @@ def _mgc_stat(distx, disty):
 
     n, m = stat_mgc_map.shape
     if m == 1 or n == 1:
-        # the global scale at is the statistic calculated at maximial nearest
+        # the global scale at is the statistic calculated at maximal nearest
         # neighbors. There is not enough local scale to search over, so
         # default to global scale
         stat = stat_mgc_map[m - 1][n - 1]
@@ -434,7 +436,7 @@ def _threshold_mgc_map(stat_mgc_map, samp_size):
     Parameters
     ----------
     stat_mgc_map : ndarray
-        All local correlations within `[-1,1]`.
+        All local correlations within ``[-1,1]``.
     samp_size : int
         The sample size of original data.
 
@@ -453,7 +455,7 @@ def _threshold_mgc_map(stat_mgc_map, samp_size):
     threshold = samp_size * (samp_size - 3)/4 - 1/2  # Beta approximation
     threshold = distributions.beta.ppf(per_sig, threshold, threshold) * 2 - 1
 
-    # the global scale at is the statistic calculated at maximial nearest
+    # the global scale at is the statistic calculated at maximal nearest
     # neighbors. Threshold is the maximum on the global and local scales
     threshold = max(threshold, stat_mgc_map[m - 1][n - 1])
 
@@ -483,19 +485,19 @@ def _smooth_mgc_map(sig_connect, stat_mgc_map):
     sig_connect : ndarray
         A binary matrix with 1's indicating the significant region.
     stat_mgc_map : ndarray
-        All local correlations within `[-1, 1]`.
+        All local correlations within ``[-1, 1]``.
 
     Returns
     -------
     stat : float
-        The sample MGC statistic within `[-1, 1]`.
+        The sample MGC statistic within ``[-1, 1]``.
     opt_scale: (float, float)
-        The estimated optimal scale as an `(x, y)` pair.
+        The estimated optimal scale as an ``(x, y)`` pair.
 
     """
     m, n = stat_mgc_map.shape
 
-    # the global scale at is the statistic calculated at maximial nearest
+    # the global scale at is the statistic calculated at maximal nearest
     # neighbors. By default, statistic and optimal scale are global.
     stat = stat_mgc_map[m - 1][n - 1]
     opt_scale = [m, n]
@@ -531,16 +533,16 @@ def _two_sample_transform(u, v):
     Parameters
     ----------
     u, v : ndarray
-        `u` and `v` have shapes `(n, p)` and `(m, p)`.
+        `u` and `v` have shapes ``(n, p)`` and ``(m, p)``.
 
     Returns
     -------
     x : ndarray
-        Concatenate `u` and `v` along the `axis = 0`. `x` thus has shape
-        `(2n, p)`.
+        Concatenate `u` and `v` along the ``axis = 0``. `x` thus has shape
+        ``(2n, p)``.
     y : ndarray
         Label matrix for `x` where 0 refers to samples that comes from `u` and
-        1 refers to samples that come from `v`. `y` thus has shape `(2n, 1)`.
+        1 refers to samples that come from `v`. `y` thus has shape ``(2n, 1)``.
 
     """
     nx = u.shape[0]
